Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(144)

Unified Diff: content/test/content_browser_test_utils_internal.h

Issue 2635933003: Convert more test helpers to base::RunLoop, fix page title checks. (Reland) (Closed)
Patch Set: Fix ClickModifierTests. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/test/test_utils.cc ('k') | content/test/content_browser_test_utils_internal.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/test/content_browser_test_utils_internal.h
diff --git a/content/test/content_browser_test_utils_internal.h b/content/test/content_browser_test_utils_internal.h
index 45755866193344be1d0a96e571ef0b25995a9ba0..bdcbb8dbefb2e446ac18f2b4a9a96b0b0e0b0765 100644
--- a/content/test/content_browser_test_utils_internal.h
+++ b/content/test/content_browser_test_utils_internal.h
@@ -17,6 +17,7 @@
#include "base/files/file_path.h"
#include "base/macros.h"
#include "base/memory/weak_ptr.h"
+#include "base/run_loop.h"
#include "cc/surfaces/surface_id.h"
#include "content/public/browser/resource_dispatcher_host_delegate.h"
#include "content/public/browser/web_contents_delegate.h"
@@ -31,7 +32,6 @@ class SurfaceManager;
namespace content {
class FrameTreeNode;
-class MessageLoopRunner;
class RenderFrameHost;
class RenderWidgetHostViewChildFrame;
class Shell;
@@ -199,8 +199,8 @@ class UrlCommitObserver : WebContentsObserver {
// The URL this observer is expecting to be committed.
GURL url_;
- // The MessageLoopRunner used to spin the message loop.
- scoped_refptr<MessageLoopRunner> message_loop_runner_;
+ // The RunLoop used to spin the message loop.
+ base::RunLoop run_loop_;
DISALLOW_COPY_AND_ASSIGN(UrlCommitObserver);
};
« no previous file with comments | « content/public/test/test_utils.cc ('k') | content/test/content_browser_test_utils_internal.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698